#
# Copyright (C) 1997 Arve Kylling
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 1, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY of FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# To obtain a copy of the GNU General Public License write to the
# Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
# USA.

#-------------------------------------------------------------------------

use lib "../tools";
use UVTools;

my $failure=0;
print "Running various libRadtran tests. This may take some time....\n";
$failure+=uvspec_test();
if ($failure) {
    printf stderr "$failure of the tests failed.\n"
}
else {
    printf stderr "All tests succeeded.\n"
}

exit;

sub uvspec_test {
    my $uvspec_failure=0;

    $test = "uvspec clear sky"; 
    my $inp = "TMP.INP";
    my $out = "TMP.OUT";
    my $exinp  = "../examples/UVSPEC_CLEAR.INP";
    my $exout  = "../examples/UVSPEC_CLEAR.OUT";
    $uvspec_failure+=uvspec_run_test($inp, $out, $exinp, $exout, $test);
    system("rm $inp $out");

    $test = "uvspec aerosol"; 
    $inp = "TMP.INP";
    $out = "TMP.OUT";
    $exinp  = "../examples/UVSPEC_CLEAR.INP ../examples/UVSPEC_AEROSOL.INP";
    $exout  = "../examples/UVSPEC_AEROSOL.OUT";
    $uvspec_failure+=uvspec_run_test($inp, $out, $exinp, $exout, $test);
    system("rm $inp $out");
    
    $test = "uvspec radiances"; 
    $inp = "TMP.INP";
    $out = "TMP.OUT";
    $exinp  = "../examples/UVSPEC_CLEAR.INP ../examples/UVSPEC_RADIANCES.INP";
    $exout  = "../examples/UVSPEC_RADIANCES.OUT";
    $uvspec_failure+=uvspec_run_test($inp, $out, $exinp, $exout, $test);
    system("rm $inp $out");
    if ($uvspec_failure) {
	printf stderr "$uvspec_failure of the uvspec tests failed.\n"
	}
    else {
	printf stderr "All uvspec tests succeeded.\n"
	}
    $uvspec_failure;
}
   
sub uvspec_run_test {
    my ($inp, $out, $exinp, $exout, $test) = @_;
    my $diffout= "TMP_DIFF.OUT";
    system("cat  $exinp > $inp");
    system("$UVTools::uvspec < $inp > $out");
    system("perl ../tools/ndiff --limit 0.01 --maxdiff 0.005 $exout $out > $diffout");
    open(FILE,$diffout);
    $ndiffs = <FILE>;
    close(FILE);
    chop $ndiffs;
    printf stderr "Found %d serious differences for $test test.\n";
    system("rm $diffout");
    $ndiffs;
}

# Local Variables:
# mode: Perl
# End:
